==> igniteui-react-charts-16.6.8.tgz: package/ES5/RelativeStrengthIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RelativeStrengthIndexIndicatorStrategy } from "./RelativeStrengthIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var RelativeStrengthIndexIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(RelativeStrengthIndexIndicator, _super);
    function RelativeStrengthIndexIndicator() {
        var _this = _super.call(this) || this;
        _this.pd = 1;
        return _this;
    }
    RelativeStrengthIndexIndicator.prototype.get_p5 = function () {
        return new RelativeStrengthIndexIndicatorStrategy();
    };
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "p5", {
        get: function () {
            return this.get_p5();
        },
        enumerable: true,
        configurable: true
    });
    RelativeStrengthIndexIndicator.prototype.get_qi = function () {
        return RelativeStrengthIndexIndicator.$;
    };
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "qi", {
        get: function () {
            return this.get_qi();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "qq", {
        get: function () {
            return typeGetValue(this.c(RelativeStrengthIndexIndicator.qr));
        },
        set: function (a) {
            this.h(RelativeStrengthIndexIndicator.qr, a);
        },
        enumerable: true,
        configurable: true
    });
    RelativeStrengthIndexIndicator.prototype.qb = function () {
        return this.qq;
    };
    RelativeStrengthIndexIndicator.prototype.qk = function (a) {
        this.qq = a;
    };
    RelativeStrengthIndexIndicator.$t = markType(RelativeStrengthIndexIndicator, 'RelativeStrengthIndexIndicator', StrategyBasedIndicator.$);
    RelativeStrengthIndexIndicator.qr = StrategyBasedIndicator.qn(14, RelativeStrengthIndexIndicator.$);
    return RelativeStrengthIndexIndicator;
}(StrategyBasedIndicator));
export { RelativeStrengthIndexIndicator };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/RelativeStrengthIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RelativeStrengthIndexIndicatorStrategy } from "./RelativeStrengthIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var RelativeStrengthIndexIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(RelativeStrengthIndexIndicator, _super);
    function RelativeStrengthIndexIndicator() {
        var _this = _super.call(this) || this;
        _this.pk = 1;
        return _this;
    }
    RelativeStrengthIndexIndicator.prototype.get_qc = function () {
        return new RelativeStrengthIndexIndicatorStrategy();
    };
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "qc", {
        get: function () {
            return this.get_qc();
        },
        enumerable: true,
        configurable: true
    });
    RelativeStrengthIndexIndicator.prototype.get_qp = function () {
        return RelativeStrengthIndexIndicator.$;
    };
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "qp", {
        get: function () {
            return this.get_qp();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "qx", {
        get: function () {
            return typeGetValue(this.c(RelativeStrengthIndexIndicator.qy));
        },
        set: function (a) {
            this.h(RelativeStrengthIndexIndicator.qy, a);
        },
        enumerable: true,
        configurable: true
    });
    RelativeStrengthIndexIndicator.prototype.qi = function () {
        return this.qx;
    };
    RelativeStrengthIndexIndicator.prototype.qr = function (a) {
        this.qx = a;
    };
    RelativeStrengthIndexIndicator.$t = markType(RelativeStrengthIndexIndicator, 'RelativeStrengthIndexIndicator', StrategyBasedIndicator.$);
    RelativeStrengthIndexIndicator.qy = StrategyBasedIndicator.qu(14, RelativeStrengthIndexIndicator.$);
    return RelativeStrengthIndexIndicator;
}(StrategyBasedIndicator));
export { RelativeStrengthIndexIndicator };
